==> idev-0.1.0.tar.gz: lib/irouter/irouter.dart <==
import 'package:flutter/material.dart';

import 'parsed_route.dart';
import 'iroute_parser.dart';
import 'common.dart';

class IRouter extends ChangeNotifier {
  final IRouteParser _parser;
  final Map<String, List<TabItem>> tabs = {};

  ParsedRoute _route;
  final Map<String, RouteBuilder> _routes;

  addTab(String tabId, List<String> urls) {
    if (tabs.containsKey(tabId)) return;
    tabs.putIfAbsent(tabId, () {
      return urls.map((e) => TabItem(e)).toList();
    });
  }

  IRouter(this._parser)
      : _route = _parser.initialRoute,
        _routes = _parser.routes;

  ParsedRoute get route => _route;

  set route(ParsedRoute route) {
    if (_route == route) {
      return;
    }

    _route = route;
    notifyListeners();
  }

  Future<void> to(String path, [int? index, String pageKey = 'ipage']) async {
    String url = path;
    if (index != null) {
      if (!url.contains(pageKey)) url += (index == 0 ? '' : ':$pageKey=$index');
      tabs[pageKey]![index].currentUrl = url;
    }
    route =
        await _parser.parseRouteInformation(RouteInformation(location: url));
  }

  int getPageId([String pageKey = 'page']) {
    if (_route.parameters.containsKey(pageKey)) {
      return _route.parameters[pageKey] as int;
    }
    return 0;
  }

  Page getPage([String? path]) {
    ParsedRoute parsed;
    if (path != null) {
      parsed = ParsedRoute(path);
    } else {
      parsed = _route;
    }

    var builder = _routes[parsed.pattern];
    if (builder == null) {
      throw '_route.pattern=${parsed.pattern} is invalid!';
    }

    return MaterialPage<void>(
        key: ValueKey(parsed.path),
        name: parsed.path,
        child:
            Builder(builder: (context) => builder(context, parsed.parameters)));
  }
}

class TabItem {
  String url;
  String currentUrl;
  Page? defaultPage;

  TabItem(this.url) : currentUrl = url;
}

class IRouterScope extends InheritedNotifier<IRouter> {
  const IRouterScope({
    required IRouter notifier,
    required Widget child,
    Key? key,
  }) : super(key: key, notifier: notifier, child: child);

  static IRouter of(BuildContext context, {listen = false}) {
    return (listen
            ? context.dependOnInheritedWidgetOfExactType<IRouterScope>()!
            : context.findAncestorWidgetOfExactType<IRouterScope>()!)
        .notifier!;
  }
}

==> idev-0.1.1.tar.gz: lib/irouter/irouter.dart <==
import 'package:flutter/material.dart';

import 'parsed_route.dart';
import 'iroute_parser.dart';
import 'common.dart';

class IRouter extends ChangeNotifier {
  final IRouteParser _parser;
  final Map<String, List<TabItem>> tabs = {};

  ParsedRoute _route;
  final Map<String, RouteBuilder> _routes;

  addTab(String tabId, List<String> urls) {
    if (tabs.containsKey(tabId)) return;
    tabs.putIfAbsent(tabId, () {
      return urls.map((e) => TabItem(e)).toList();
    });
  }

  static IRouter of(BuildContext context, {listen = false}) {
    return (listen
            ? context.dependOnInheritedWidgetOfExactType<_IRouterScope>()!
            : context.findAncestorWidgetOfExactType<_IRouterScope>()!)
        .notifier!;
  }

  //Bug!!! 这里错误，应是stateKey: _providerStateKey
  static Widget provider(IRouter notifier, Widget app) {
    return _IRouterScope(notifier: notifier, child: app);
  }

  static Future<void> push(context, String path,
      [int? index, String pageKey = 'ipage']) {
    return IRouter.of(context).to(path, index, pageKey);
  }

  static void pop(context) {
    return Navigator.of(context).pop();
  }

  IRouter(this._parser)
      : _route = _parser.initialRoute,
        _routes = _parser.routes;

  ParsedRoute get route => _route;

  set route(ParsedRoute route) {
    if (_route == route) {
      return;
    }

    _route = route;
    notifyListeners();
  }

  Future<void> to(String path, [int? index, String pageKey = 'ipage']) async {
    String url = path;
    if (index != null) {
      if (!url.contains(pageKey)) url += (index == 0 ? '' : ':$pageKey=$index');
      tabs[pageKey]![index].currentUrl = url;
    }
    route =
        await _parser.parseRouteInformation(RouteInformation(location: url));
  }

  int getPageId([String pageKey = 'page']) {
    if (_route.parameters.containsKey(pageKey)) {
      return _route.parameters[pageKey] as int;
    }
    return 0;
  }

  Page getPage([String? path]) {
    ParsedRoute parsed;
    if (path != null) {
      parsed = ParsedRoute(path);
    } else {
      parsed = _route;
    }

    var builder = _routes[parsed.pattern];
    if (builder == null) {
      throw '_route.pattern=${parsed.pattern} is invalid!';
    }

    return MaterialPage<void>(
        key: ValueKey(parsed.path),
        name: parsed.path,
        child:
            Builder(builder: (context) => builder(context, parsed.parameters)));
  }
}

class TabItem {
  String url;
  String currentUrl;
  Page? defaultPage;

  TabItem(this.url) : currentUrl = url;
}

class _IRouterScope extends InheritedNotifier<IRouter> {
  const _IRouterScope({
    required IRouter notifier,
    required Widget child,
    Key? key,
  }) : super(key: key, notifier: notifier, child: child);

  // static IRouter of(BuildContext context, {listen = false}) {
  //   return (listen
  //           ? context.dependOnInheritedWidgetOfExactType<_IRouterScope>()!
  //           : context.findAncestorWidgetOfExactType<_IRouterScope>()!)
  //       .notifier!;
  // }
}
